GenerateSpace class

Constructors

GenerateSpace({String? classRadical = "Space", String? generateForFieldStartingWith = "space", bool removePrefix = false, bool radicalFirst = true, bool avoidPrefixRepetition = true})
const

Properties

avoidPrefixRepetition → bool
finalinherited
classRadical → String?
finalinherited
generateForFieldStartingWith → String?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
radicalFirst → bool
finalinherited
removePrefix → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited